@@ -97,6 +97,10 @@ extern INT32 (__cdecl *BurnExtCartridgeSetupCallback)(BurnCartrigeCommand nComma
 // Application-defined colour conversion function
 extern UINT32 (__cdecl *BurnHighCol) (INT32 r, INT32 g, INT32 b, INT32 i);
 
+#define HighCol16(r,g,b,i) ((r<<8)&0xf800)|((g<<3)&0x07e0)|(b>>3)
+#define HighCol15(r,g,b,i) ((r<<7)&0x7c00)||((g<<2)&0x03e0)|(b>>3)
+
+
 // ---------------------------------------------------------------------------
 
 extern UINT32 nCurrentFrame;
