@@ -391,7 +391,7 @@ void load_keymap(char * nm)
 	signed long argd;
     char line[256];
     char fullpath[256];
-    strcpy(fullpath,"/home/user/.config/fba/");
+    strcpy(fullpath,"./config/games/");
     strcat(fullpath,nm);
     strcat(fullpath,".kmp");
     if ((f = fopen(fullpath,"r")) == NULL) f = fopen("/home/user/.config/fba/default.kmp", "r");
