@@ -49,7 +49,6 @@ SDL_Surface* SDL_VideoBuffer;
 #define FBIO_WAITFORVSYNC _IOW('F', 0x20, __u32)
 unsigned long fbdev;
 int vb;
-
     int scaleheight=480;
     int scalewidth=800;
 
@@ -124,6 +123,7 @@ void gp2x_initialize()
         printf("sdl failed to init\n");
     }			// Initialize SDL
     myscreen = SDL_SetVideoMode(scalewidth, scaleheight, 16, SDL_FULLSCREEN | SDL_SWSURFACE  | SDL_DOUBLEBUF);
+    //myscreen = SDL_SetVideoMode(WINDOW_WIDTH, WINDOW_HEIGHT, 16, SDL_HWSURFACE | SDL_HWPALETTE | SDL_DOUBLEBUF);
     if(!myscreen)
 	{
 		printf("SDL_SetVideoMode screen not initialised.\n");								// debug output example for serial cable
@@ -161,7 +161,6 @@ void gp2x_terminate(char *frontend)
 {
     struct stat info;
     SDL_Quit();
-    printf("front ent %s\n",frontend);
     if( (lstat(frontend, &info) == 0) && S_ISREG(info.st_mode) )
 	{
 	char path[256];
@@ -174,14 +173,11 @@ void gp2x_terminate(char *frontend)
 			*p = '\0';
 			chdir(path);
 		}
-    printf("execute %s\n",frontend);
 		execl(frontend, frontend, NULL);
 	}
 
 }
 
-
-
 int get_pc_keyboard()
 {
     int pckeydata=0;
